@@ -32,6 +32,7 @@ tab_df_content <- function(
   include.table.tag = TRUE,
   no.last.table.row = FALSE,
   show.header = TRUE,
+  zeroinf = FALSE,
   ...) {
 
   # save no of rows and columns
@@ -122,6 +123,13 @@ tab_df_content <- function(
   }
 
 
+  if (isTRUE(zeroinf)) {
+    page.content <- paste0(page.content, "  <tr>\n")
+    page.content <- paste0(page.content, sprintf("    <td colspan=\"%i\" class=\"zeroparts\">Count Model</td>\n", colcnt + 1))
+    page.content <- paste0(page.content, "  </tr>\n")
+  }
+
+
   # subsequent rows ----
 
   for (rcnt in 1:rowcnt) {
@@ -164,7 +172,7 @@ tab_df_content <- function(
         arcstring,
         mcc,
         ccnt,
-        mydf[rcnt, ccnt])
+        mydf[[ccnt]][rcnt])
       )
     }
 
