@@ -23,9 +23,23 @@ data(mtcars)
 m.mtcars <- lm(mpg ~ cyl + hp + wt, data = mtcars)
 tab_model(m.mtcars)
 
+## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+set.seed(2)
+dat <- data.frame(
+  y = runif(100, 0, 100),
+  drug = as.factor(sample(c("nonsense", "useful", "placebo"), 100, TRUE)),
+  group = as.factor(sample(c("control", "treatment"), 100, TRUE))
+)
+
+pretty_names <- lm(y ~ drug * group, data = dat)
+tab_model(pretty_names)
+
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 tab_model(m1, auto.label = FALSE)
 
+## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+tab_model(pretty_names, auto.label = FALSE)
+
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 tab_model(m1, m2)
 
@@ -103,7 +117,10 @@ tab_model(model, show.reflvl = TRUE)
 tab_model(model, show.reflvl = TRUE, prefix.labels = "varname")
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
-tab_model(m1, m2, p.style = "a")
+tab_model(m1, m2, p.style = "stars")
+
+## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
+tab_model(m1, m2, p.style = "scientific", digits.p = 2)
 
 ## -----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 # example, coefficients are "c161sex2" or "c172code3"
